==> spip_3.2.11.orig.tar.xz: plugins-dist/sites/lang/sites_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=sv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Uppkopplingen misslyckades: Källfilen är antingen otydbar eller så innehåller den ingen artikel. ',
	'avis_echec_syndication_02' => 'Uppkopplingen misslyckades: Det var inte möjligt att komma åt syndikeringsfilen.',
	'avis_site_introuvable' => 'Webbplatsen hittades inte',
	'avis_site_syndique_probleme' => 'OBS! Syndikeringen av den här sajten har stött på ett problem ; Därför är funktionen tillfälligt avbruten. Var vänlig och verifiera adressen till sajtens syndikeringsfil (<b>@url_syndic@</b>), och försök att göra en ny hämtning av information.',
	'avis_sites_probleme_syndication' => 'Dessa sajter har ett syndikeringsproblem',
	'avis_sites_syndiques_probleme' => 'Det har uppstått ett problem med syndikeringen av sajterna',

	// B
	'bouton_radio_modere_posteriori' => 'moderering i efterhand', # MODIF
	'bouton_radio_modere_priori' => 'moderering i förhand', # MODIF
	'bouton_radio_non_syndication' => 'Ingen syndikering',
	'bouton_radio_syndication' => 'Syndikering:',

	// E
	'entree_adresse_fichier_syndication' => 'Adress till syndikeringsfil:',
	'entree_adresse_site' => '<b>Webbplats URL</b> [Krävs]',
	'entree_description_site' => 'Beskrivning av webbplats',

	// F
	'form_prop_nom_site' => 'Sajtens namn',

	// I
	'icone_modifier_site' => 'Editera sajten',
	'icone_referencer_nouveau_site' => 'Länka en ny sajt',
	'icone_voir_sites_references' => 'Visa länkade sajter',
	'info_1_site' => '1 sajt',
	'info_a_valider' => '[att godkännas]',
	'info_bloquer' => 'Block',
	'info_bloquer_lien' => 'blockera länken',
	'info_derniere_syndication' => 'Den sista syndikeringen av den här sajten skedde den',
	'info_liens_syndiques_1' => 'syndikerade länkar',
	'info_liens_syndiques_2' => 'i väntan på validering.',
	'info_nom_site_2' => '<b>Sajtens namn</b> [krävs]',
	'info_panne_site_syndique' => 'Syndikerad sajt fungerar ej',
	'info_probleme_grave' => 'fel av',
	'info_question_proposer_site' => 'Vem kan föreslå länkar till sajter?',
	'info_retablir_lien' => 'återskapa den här länken',
	'info_site_attente' => 'Webbsajten väntar på godkännande',
	'info_site_propose' => 'Sajt föreslagen den:',
	'info_site_reference' => 'Länkade sajter ',
	'info_site_refuse' => 'Webbsajten refuserad',
	'info_site_syndique' => 'Denna sajt är syndikerad...', # MODIF
	'info_site_valider' => 'Sajter som väntar på godkännande',
	'info_sites_referencer' => 'Länka till en sajt',
	'info_sites_refuses' => 'Refuserade sajter',
	'info_statut_site_1' => 'Denna sajt är:',
	'info_statut_site_2' => 'Publicerad',
	'info_statut_site_3' => 'Inskickad',
	'info_statut_site_4' => 'I papperskorgen', # MODIF
	'info_syndication' => 'syndikering:',
	'info_syndication_articles' => 'artikel(ar)',
	'item_bloquer_liens_syndiques' => 'Stoppa syndikerade länkar från godkännande',
	'item_gerer_annuaire_site_web' => 'Administrera webbsajt-katalogen',
	'item_non_bloquer_liens_syndiques' => 'Blockera inte länkar som kommer ifrån syndikering',
	'item_non_gerer_annuaire_site_web' => 'Avaktivera webbsajt-katalogen',
	'item_non_utiliser_syndication' => 'Använd inte automatisk syndikering',
	'item_utiliser_syndication' => 'Använd automatisk syndikering',

	// L
	'lien_mise_a_jour_syndication' => 'Uppdatera nu',
	'lien_nouvelle_recuperation' => 'Försök att hämta datum igen',

	// S
	'syndic_lien_obsolete' => 'Trasig länk',
	'syndic_option_resume_non' => 'det fullständiga innehållet i artiklarna (i HTML-format)',
	'syndic_option_resume_oui' => 'en enkel sammanfattning (i text-format)',
	'syndic_options' => 'Alternativ för syndikering :',

	// T
	'texte_non_fonction_referencement' => 'Du kan välja att inte använda den automatiska funktionen och i stället mata in information om sajetn manuellt...', # MODIF
	'texte_syndication' => 'If a site allows it, it is possible to retrieve automatically
		the list of its latest material. To achieve this, you must activate the syndication. 
		<blockquote><i>Some hosts disable this function; 
		in this case, you cannot use the content syndication
		from your site.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Syndikerade artiklar från den här sajten',
	'titre_dernier_article_syndique' => 'Senaste syndikerade artiklar',
	'titre_page_sites_tous' => 'Refererade webbplatser',
	'titre_site_numero' => 'WEBBPLATS NUMMER',
	'titre_sites_references_rubrique' => 'Refererade webbplatser i den här avdelningen',
	'titre_sites_tous' => 'Refererade webbplatser'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=sv
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'Uppkopplingen misslyckades: Källfilen är antingen otydbar eller så innehåller den ingen artikel. ',
	'avis_echec_syndication_02' => 'Uppkopplingen misslyckades: Det var inte möjligt att komma åt syndikeringsfilen.',
	'avis_site_introuvable' => 'Webbplatsen hittades inte',
	'avis_site_syndique_probleme' => 'OBS! Syndikeringen av den här sajten har stött på ett problem ; Därför är funktionen tillfälligt avbruten. Var vänlig och verifiera adressen till sajtens syndikeringsfil (<b>@url_syndic@</b>), och försök att göra en ny hämtning av information.',
	'avis_sites_probleme_syndication' => 'Dessa sajter har ett syndikeringsproblem',
	'avis_sites_syndiques_probleme' => 'Det har uppstått ett problem med syndikeringen av sajterna',

	// B
	'bouton_radio_modere_posteriori' => 'moderering i efterhand', # MODIF
	'bouton_radio_modere_priori' => 'moderering i förhand', # MODIF
	'bouton_radio_non_syndication' => 'Ingen syndikering',
	'bouton_radio_syndication' => 'Syndikering:',

	// E
	'entree_adresse_fichier_syndication' => 'Adress till syndikeringsfil:',
	'entree_adresse_site' => '<b>Webbplats URL</b> [Krävs]',
	'entree_description_site' => 'Beskrivning av webbplats',

	// F
	'form_prop_nom_site' => 'Sajtens namn',

	// I
	'icone_modifier_site' => 'Editera sajten',
	'icone_referencer_nouveau_site' => 'Länka en ny sajt',
	'icone_voir_sites_references' => 'Visa länkade sajter',
	'info_1_site' => '1 sajt',
	'info_a_valider' => '[att godkännas]',
	'info_bloquer' => 'Block',
	'info_bloquer_lien' => 'blockera länken',
	'info_derniere_syndication' => 'Den sista syndikeringen av den här sajten skedde den',
	'info_liens_syndiques_1' => 'syndikerade länkar',
	'info_liens_syndiques_2' => 'i väntan på validering.',
	'info_nom_site_2' => '<b>Sajtens namn</b> [krävs]',
	'info_panne_site_syndique' => 'Syndikerad sajt fungerar ej',
	'info_probleme_grave' => 'fel av',
	'info_question_proposer_site' => 'Vem kan föreslå länkar till sajter?',
	'info_retablir_lien' => 'återskapa den här länken',
	'info_site_attente' => 'Webbsajten väntar på godkännande',
	'info_site_propose' => 'Sajt föreslagen den:',
	'info_site_reference' => 'Länkade sajter ',
	'info_site_refuse' => 'Webbsajten refuserad',
	'info_site_syndique' => 'Denna sajt är syndikerad...', # MODIF
	'info_site_valider' => 'Sajter som väntar på godkännande',
	'info_sites_referencer' => 'Länka till en sajt',
	'info_sites_refuses' => 'Refuserade sajter',
	'info_statut_site_1' => 'Denna sajt är:',
	'info_statut_site_2' => 'Publicerad',
	'info_statut_site_3' => 'Inskickad',
	'info_statut_site_4' => 'I papperskorgen', # MODIF
	'info_syndication' => 'syndikering:',
	'info_syndication_articles' => 'artikel(ar)',
	'item_bloquer_liens_syndiques' => 'Stoppa syndikerade länkar från godkännande',
	'item_gerer_annuaire_site_web' => 'Administrera webbsajt-katalogen',
	'item_non_bloquer_liens_syndiques' => 'Blockera inte länkar som kommer ifrån syndikering',
	'item_non_gerer_annuaire_site_web' => 'Avaktivera webbsajt-katalogen',
	'item_non_utiliser_syndication' => 'Använd inte automatisk syndikering',
	'item_utiliser_syndication' => 'Använd automatisk syndikering',

	// L
	'lien_mise_a_jour_syndication' => 'Uppdatera nu',
	'lien_nouvelle_recuperation' => 'Försök att hämta datum igen',

	// S
	'syndic_lien_obsolete' => 'Trasig länk',
	'syndic_option_resume_non' => 'det fullständiga innehållet i artiklarna (i HTML-format)',
	'syndic_option_resume_oui' => 'en enkel sammanfattning (i text-format)',
	'syndic_options' => 'Alternativ för syndikering :',

	// T
	'texte_non_fonction_referencement' => 'Du kan välja att inte använda den automatiska funktionen och i stället mata in information om sajetn manuellt...', # MODIF
	'texte_syndication' => 'If a site allows it, it is possible to retrieve automatically
		the list of its latest material. To achieve this, you must activate the syndication. 
		<blockquote><i>Some hosts disable this function; 
		in this case, you cannot use the content syndication
		from your site.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Syndikerade artiklar från den här sajten',
	'titre_dernier_article_syndique' => 'Senaste syndikerade artiklar',
	'titre_page_sites_tous' => 'Refererade webbplatser',
	'titre_site_numero' => 'WEBBPLATS NUMMER',
	'titre_sites_references_rubrique' => 'Refererade webbplatser i den här avdelningen',
	'titre_sites_tous' => 'Refererade webbplatser',
];
